@@ -510,6 +510,27 @@ our $charset = {
 
 					#######################################
 
+	{
+		name     => 'sql_temporality_callback',
+		label_en => 'Internal sub passed to DBIx::ModelUpdate when $conf -> {db_temporality} is on.',
+		label_ru => ' ,  DBIx::ModelUpdate    $conf -> {db_temporality}.',
+#		see_also => [qw(sql_select_col)],
+	},
+
+					#######################################
+
+	{
+		name     => 'sql_select_ids',
+		syn      => <<EO,
+	my \$ids = sql_select_ids ('SELECT id FROM users WHERE id_role = ?', 1);
+EO
+		label_en => 'Returns ID list suitable for IN () clause',
+		label_ru => '  ID,      IN ().  :  -1.',
+		see_also => [qw(sql_select_col)],
+	},
+
+					#######################################
+
 	{
 		name     => 'b64u_encode',
 		syn      => <<EO,
